/****************************************************************************
** $Id$
**
** Implementation of QAccessible class for Unix
**
** Copyright (C) 2000-2001 Trolltech AS.  All rights reserved.
**
** This file is part of the kernel module of the Qt GUI Toolkit.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses may use this file in accordance with the Qt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/qpl/ for QPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "qaccessible.h"

#if defined(QT_ACCESSIBILITY_SUPPORT)

#include "qapplication.h"
#include "qlibrary.h"
#include "qwidgetlist.h"

typedef void(*QSetRootObject)(QAccessibleInterface *);
static QSetRootObject qSetRootObject = 0;
typedef void(*QNotifyAccessibilityUpdate)(QAccessible::Event, QAccessibleInterface*, int);
static QNotifyAccessibilityUpdate qNotifyAccessibilityUpdate = 0;

void QAccessible::initialize()
{
    static bool initialized = FALSE;
    if (initialized)
	return;
    initialized = TRUE;

    if (!qSetRootObject)
	qSetRootObject = (QSetRootObject)QLibrary::resolve("qaccclient", "qSetRootObject");
    if (!qNotifyAccessibilityUpdate)
	qNotifyAccessibilityUpdate = (QNotifyAccessibilityUpdate)QLibrary::resolve("qaccclient", "qNotifyAccessibilityUpdate");

    if (!qSetRootObject)
	return;

    QAccessibleInterface *iface = 0;
    QWidget *root = qApp->mainWidget();
    if (!root) {
	QWidgetList *list = qApp->topLevelWidgets();
	root = list->getFirst();
	delete list;
    }
    if (!root)
	return;

    QAccessible::queryAccessibleInterface(root, &iface);
    if (!iface)
	return;
    qSetRootObject(iface);
    iface->release();
}

void QAccessible::cleanup()
{
}

void QAccessible::updateAccessibility( QObject *o, int who, Event reason )
{
    Q_ASSERT(o);

    if (!qNotifyAccessibilityUpdate)
	return;

    QAccessibleInterface *iface = 0;
    QAccessible::queryAccessibleInterface(o, &iface);
    if (iface)
	qNotifyAccessibilityUpdate(reason, iface, who);
}

#endif
